@@ -12,7 +12,7 @@ use fast_image_resize::{ImageData, MulDiv};
 mod utils;
 
 pub fn bench_downscale_rgba(bench: &mut Bench) {
-    let src_image = utils::get_big_rgba_image();
+    let src_image = &utils::get_big_rgba_image();
     let new_width = NonZeroU32::new(852).unwrap();
     let new_height = NonZeroU32::new(567).unwrap();
 
@@ -30,7 +30,7 @@ pub fn bench_downscale_rgba(bench: &mut Bench) {
         };
         bench.task(format!("image - {}", alg_name), |task| {
             task.iter(|| {
-                imageops::resize(&src_image, new_width.get(), new_height.get(), filter);
+                imageops::resize(src_image, new_width.get(), new_height.get(), filter);
             })
         });
     }
@@ -64,17 +64,13 @@ pub fn bench_downscale_rgba(bench: &mut Bench) {
     }
 
     // fast_image_resize crate;
-    for cpu_ext in [
-        CpuExtensions::None,
-        CpuExtensions::Sse4_1,
-        CpuExtensions::Avx2,
-    ] {
-        let ext_name = match cpu_ext {
-            CpuExtensions::None => "rust",
-            CpuExtensions::Sse4_1 => "sse4.1",
-            CpuExtensions::Avx2 => "avx2",
-            _ => continue,
-        };
+    let mut cpu_ext_and_name = vec![(CpuExtensions::None, "rust")];
+    #[cfg(target_arch = "x86_64")]
+    {
+        cpu_ext_and_name.push((CpuExtensions::Sse4_1, "sse4.1"));
+        cpu_ext_and_name.push((CpuExtensions::Avx2, "avx2"));
+    }
+    for (cpu_ext, ext_name) in cpu_ext_and_name {
         for alg_name in alg_names {
             let resize_alg = match alg_name {
                 "Nearest" => ResizeAlg::Nearest,
@@ -83,15 +79,10 @@ pub fn bench_downscale_rgba(bench: &mut Bench) {
                 "Lanczos3" => ResizeAlg::Convolution(FilterType::Lanczos3),
                 _ => return,
             };
-            let buf: Vec<u32> = src_image
-                .as_raw()
-                .chunks_exact(4)
-                .map(|p| u32::from_le_bytes([p[0], p[1], p[2], p[3]]))
-                .collect();
-            let src_image_data = ImageData::from_pixels(
+            let src_image_data = ImageData::from_vec_u8(
                 NonZeroU32::new(src_image.width()).unwrap(),
                 NonZeroU32::new(src_image.height()).unwrap(),
-                buf,
+                src_image.as_raw().clone(),
                 PixelType::U8x4,
             )
             .unwrap();
