@@ -1,4 +1,5 @@
 #![doc = include_str!("../README.md")]
+
 pub use alpha::{MulDiv, MulDivImageError, MulDivImagesError};
 pub use convolution::FilterType;
 pub use errors::{CropBoxError, ImageBufferError, ImageRowsError, InvalidBufferSizeError};
@@ -11,6 +12,6 @@ mod convolution;
 mod errors;
 mod image_data;
 mod image_view;
-mod optimisations;
 mod resizer;
+#[cfg(target_arch = "x86_64")]
 mod simd_utils;
